"""Configuration module for monitoring websocket server."""

from .config import *

__all__ = [
    # WebSocket configuration
    'WEBSOCKET_HOST', 'WEBSOCKET_PORT', 'WEBSOCKET_MAX_CLIENTS',
    'WEBSOCKET_CLOSE_CODE_CAPACITY', 'WEBSOCKET_SEND_TIMEOUT',
    'WEBSOCKET_BROADCAST_SEMAPHORE_LIMIT',
    
    # Monitoring intervals
    'MONITOR_INTERVAL', 'EXPORT_INTERVAL', 'PROCESSOR_CHECK_INTERVAL',
    'PROCESSOR_FALLBACK_INTERVAL', 'CLEANUP_INTERVAL', 'HISTORY_TTL',
    'ALERT_COOLDOWN', 'ALERT_CLEANUP_INTERVAL',
    'MONITORING_COLLECTION_INTERVAL', 'CPU_PERCENT_INTERVAL',
    
    # Queue and history sizes
    'MAX_SNAPSHOTS_HISTORY', 'ALERT_HISTORY_SIZE', 'DATA_QUEUE_SIZE',
    'COMMAND_QUEUE_SIZE', 'RESPONSE_QUEUE_SIZE', 'LAST_ALERTS_DEQUE_SIZE',
    
    # Performance limits
    'THREAD_POOL_WORKERS', 'MAX_ERROR_COUNT', 'MAX_ALERTS_COUNT',
    'MAX_PROCESSOR_INTERVAL', 'MAX_MONITORING_INTERVAL',
    
    # Alert thresholds
    'MEMORY_WARNING_THRESHOLD', 'MEMORY_CRITICAL_THRESHOLD',
    'DISK_WARNING_THRESHOLD', 'DISK_CRITICAL_THRESHOLD',
    'DISK_MIN_FREE_GB', 'DISK_WARNING_FREE_GB', 'DISK_CRITICAL_FREE_GB',
    
    # Timeouts
    'SERVICE_START_TIMEOUT', 'SERVICE_STOP_TIMEOUT', 'COMMAND_PUT_TIMEOUT',
    'RESPONSE_GET_TIMEOUT', 'EXPORT_RESPONSE_TIMEOUT', 'BROADCAST_TIMEOUT',
    'WEBSOCKET_SERVER_READY_WAIT', 'THREAD_JOIN_TIMEOUT',
    
    # Paths and files
    'DEFAULT_EXPORT_DIR', 'DEFAULT_DISK_PATH',
    
    # Export configuration
    'EXPORT_COMPRESS_DEFAULT', 'EXPORT_PRETTY_PRINT_DEFAULT',
    'EXPORT_DATE_IN_FILENAME_DEFAULT',
    
    # Delays and retry
    'ERROR_RETRY_DELAY', 'MAIN_LOOP_DELAY', 'ERROR_LOOP_DELAY',
    
    # Change thresholds
    'CPU_USAGE_CHANGE_THRESHOLD', 'MEMORY_USAGE_CHANGE_THRESHOLD',
    'DISK_USAGE_CHANGE_THRESHOLD',
    
    # Other constants
    'OLD_ALERT_AGE', 'SIGNIFICANT_DIGITS', 'MAX_FILE_SIZE_DEFAULT',
    'SMTP_PORT_DEFAULT', 'HTTP_TIMEOUT_DEFAULT', 'MAX_MONITOR_ERRORS',
    'COMPRESSION_FACTOR', 'JSON_INDENT',
    
    # Logging configuration
    'DEFAULT_LOG_LEVEL', 'DEFAULT_LOG_FORMAT',
]